// Copyright 1999-2016. Parallels IP Holdings GmbH. All Rights Reserved.

define(function () {
    var ce = Jsw.createElement;

    return Class.create(Jsw.ActiveList, {
        _initConfiguration: function ($super, config) {
            $super(config);
            this.domains = this._getConfigParam('domains', []);
        },

        itemCaptionHeadView: function ($super, item) {
            var view = $super(item);

            var users = item.users.slice(0, 4);

            view.children.push(ce(".caption-summary",
                ce(".caption-summary-wrap",
                    ce("span.summary-item",
                        ce("b", this.lmsg('hostLabel') + (item.serverHost + (item.serverPort > 0 ? ":" + item.serverPort : "") + " (" + item.typeTitle + ")").escapeHTML()),
                        item.hasConnectionError ? [" ", ce("span.state-error", this.lmsg('serverUnavailable'))] : ""
                    ),
                    ce("span.summary-item",
                        item.users.length ? [
                            this.lmsg('users'), ": ",
                            ce("b",
                                users.map(function (user) {
                                    return '<a href="' + this.urls['edit-user'] + '/id/' + user.id + '">' + user.login + '</a>';
                                }.bind(this)).join(', ') + (item.users.length > users.length ? ',&nbsp;...' : '')
                            )
                        ] : [
                            ce("span.state-error", this.lmsg('noUsers')),
                            item.hasConnectionError ? "" : [" ", ce("a", {"href": this.urls['create-user'] + '/database/' + item.id}, "[" + this.lmsg('addUser') + "]")]
                        ]
                    ),
                    item.hasConnectionError ? "" : ce("span.summary-item.ajax-loading", this.lmsg('calculatingSize'))
                )
            ));

            return view;
        },

        itemCaptionHeadWrapView: function ($super, item) {
            var view = $super(item);

            if (item.allowWebadmin) {
                view.children.unshift(ce("span.caption-head-widget",
                    ce("a.btn", {"onclick": this.itemActions.openWebAdmin.bind(this, item)},
                        item.webAdminTitle
                    )
                ));
            }

            var relatedDomains = this.domains.filter(function (domain) {
                return item.id == domain.lastDatabaseSelectedId;
            }).map(function (domain) {
                return domain.name;
            });

            view.children.push(ce("span.caption-head-action",
                item.isUsedByApp ? (
                    item.assignedDomainName ? this.lmsg('relatedToDomains', {"domains": item.assignedDomainName}) : ""
                ) : (
                    relatedDomains.length > 0 ? [
                        this.lmsg('relatedToDomains', {"domains": relatedDomains.join(", ")}), " ",
                        ce("a.toggler", {"onclick": this.changeRelatedDomains.bind(this, item)}, this.lmsg('changeRelatedDomain'))
                    ] : ce("a.toggler", {"onclick": this.changeRelatedDomains.bind(this, item)}, this.lmsg('noRelatedDomains'))
                )
            ));

            if (!item.isUsedByApp) {
                view.children.push(ce("span.caption-head-action", {"style": "display: none;"},
                    this.lmsg('relatedToDomains', {"domains": ""}),
                    ce("select",
                        ce("option", {"value": ""}, this.lmsg('noDomainRelations')),
                        this.domains.map(function (domain) {
                            return ce("option" + (item.id == domain.lastDatabaseSelectedId ? "[selected]" : ""), {"value": domain.id}, domain.name)
                        })
                    ), " ",
                    ce("a.btn", {"onclick": this.setRelatedDomains.bind(this, item)}, this.lmsg('buttonOk'))
                ));
            }
            return view;
        },

        render: function ($super) {
            $super();

            new Ajax.Request(this.urls['list-size-data'], {
                method: 'get',
                onSuccess: function(transport) {
                    transport.responseText.evalJSON().forEach(function (item) {
                        var el = this.getItemElement(item);
                        var hostItemEl = el.down('.summary-item:first');
                        if (hostItemEl.down('.state-error')) {
                            return;
                        }
                        if (item.hasConnectionError) {
                            hostItemEl.insert(' <span class="state-error">' + this.lmsg('serverUnavailable') + '</span>');
                            el.down('.summary-item:last').remove();
                        } else {
                            el.down('.summary-item:last').replace(
                                '<span class="summary-item">' + this.lmsg('tables') + ': <b>' + item.tables + '</b></span>' +
                                '<span class="summary-item">' + this.lmsg('size') + ': <b>' + item.size + '</b></span>'
                            );
                        }
                    }.bind(this));
                }.bind(this)
            });
        },

        changeRelatedDomains: function (item) {
            var actions = this.getItemElement(item).select('.caption-head-action');
            actions[0].hide();
            actions[1].show();
        },

        setRelatedDomains: function (item) {
            var el = this.getItemElement(item);
            Jsw.redirectPost(this.urls['set-related-domain'], {
                id: item.id,
                domainId: el.down('.caption-head-action select').getValue()
            });
        }
    });
});
