// Copyright 1999-2016. Parallels IP Holdings GmbH. All Rights Reserved.

define(function () {
    var ce = Jsw.createElement;
    return function (pkg, urls) {
        var locale = Jsw.Locale.getSection('controllers.module.catalog-details');
        var installAction = function (btn, uuid) {
            btn.addClassName('disabled');
            btn.update('<span class="wait">' + locale.lmsg('wait') + '</span>');
            Jsw.redirectPost(urls['install-from-catalog'], {'uuid' : uuid});
        };
        var renderActions = function () {
            var actions = [];
            if (pkg.status === 'same' || pkg.status === 'different') {
                actions.push(ce('.catalog-item-status', [
                    ce('i.icon-ok'),
                    ' ',
                    locale.lmsg('extensionInstalled')
                ]));
            }
            if (pkg.buy_url) {
                actions.push(ce('a.btn.action', {
                    href:pkg.buy_url,
                    target:'_blank'
                }, locale.lmsg('buttonBuyNow')));
            }
            if (pkg.status === 'absent') {
                actions.push(ce('a.btn', {
                    onclick: function (event) {
                        event.preventDefault();
                        installAction(this, pkg.uuid);
                    }
                }, locale.lmsg('buttonInstall')));
            }
            if (pkg.status === 'different') {
                actions.push(ce('a.btn', {
                    onclick: function (event) {
                        event.preventDefault();
                        installAction(this, pkg.uuid);
                    }
                }, locale.lmsg('buttonUpgrade')));
            }
            return actions;
        };
        var renderMarkdown = function (data, element) {
            require(["externals/marked"], function (marked) {
                marked(data, {
                    sanitize: true
                }, function (error, html) {
                    if (error) {
                        throw error;
                    }
                    element.innerHTML = html;
                });
            });
        };
        var renderRich = function (rich, fallback) {
            if (rich && rich.md) {
                return cuttable(ce('.markdown', {
                    onrender: renderMarkdown.bind(null, rich.md)
                }));
            }
            if (rich && rich.plain) {
                return cuttable(ce('pre.plaintext', rich.plain.escapeHTML()));
            }
            if (fallback) {
                return ce('p', fallback.escapeHTML());
            }
            return '';
        };
        var renderSlider = function (current) {
            return new Jsw.PopupSlider({
                title: pkg.name,
                slides: pkg.screenshots.map(function (screenshot) {
                    return '<img class="slider-image" src="' + screenshot.screenshot.escapeHTML() + '">';
                }),
                current: current
            });
        };
        var cuttable = function (content) {
            return ce('.content-cuttable', {
                onrender: function (element) {
                    var contentElement = element.down('.content-cuttable-content');
                    if (contentElement.scrollHeight <= contentElement.getHeight()) {
                        // TODO handle small content
                    }
                    element.addClassName('content-cuttable-collapse');
                    var showMore = ce('.content-cuttable-action', ce('a', {
                        onclick: function (event) {
                            event.preventDefault();
                            element.toggleClassName('content-cuttable-collapse');
                            element.toggleClassName('content-cuttable-expand');
                            this.update(element.hasClassName('content-cuttable-collapse') ?
                                locale.lmsg('showMore') : locale.lmsg('showLess'));
                        }
                    }, locale.lmsg('showMore')));
                    Jsw.render(element, showMore);
                }
            }, ce('.content-cuttable-content', content));
        };
        return ce('.catalog-overview', ce('.catalog-overview-details', ce('.catalog-overview-block', [
            ce('.catalog-overview-content', [
                ce('.catalog-overview-content-block.catalog-overview-info', [
                    ce('.catalog-overview-info-icon', ce('img', {src: pkg.icon})),
                    ce('.catalog-overview-info-details', [
                        ce('h3.catalog-overview-info-name', pkg.name.escapeHTML()),
                        ce('.catalog-overview-info-version', locale.lmsg('packageVersion', {
                            version: (pkg.version + '-' + pkg.release).escapeHTML()
                        })),
                        pkg.vendor ? ce('.catalog-overview-info-vendor', locale.lmsg('packageVendor', {
                            vendor: pkg.vendor.escapeHTML()
                        })) : null
                    ]),
                    ce('.catalog-overview-info-actions', renderActions())
                ]),
                ce('.catalog-overview-content-block.catalog-overview-description', [
                    ce('h4', locale.lmsg('packageDescription')),
                    renderRich(pkg.extended_description, pkg.description)
                ]),
                pkg.changelog && Object.keys(pkg.changelog).length ?
                ce('.catalog-overview-content-block.catalog-overview-changelog', [
                    ce('h4', locale.lmsg('packageChangelog')),
                    renderRich(pkg.changelog)
                ]) : null,
                ce('.catalog-overview-content-block.catalog-overview-screenshots',
                    ce('.catalog-overview-img', pkg.screenshots.map(function (screenshot, index) {
                        return ce('a', {
                            onclick: function (event) {
                                event.preventDefault();
                                renderSlider(index);
                            }
                        }, ce('img', {src: screenshot.thumbnail}));
                    }))
                )
            ])
        ])));
    };
});
