// Copyright 1999-2016. Parallels IP Holdings GmbH. All Rights Reserved.

define([
    "./popup-packages-base"
], function (PopupPackagesBase) {
    return Class.create(PopupPackagesBase, {
        _showLockStatus: true,

        render: function ($super) {
            $super();

            this.setBoxType('form-box');
            this.setTitle(this.lmsg('popupUpdateTitle'));
            this._updateButton(this._buttonOk, {disabled: true});

            $(this._contentAreaId).update('<div class="ajax-loading">' + this.lmsg('loading') + '</div>');

            var context = this;
            new Ajax.Request(
                Jsw.prepareUrl(this._urls.packageUpdateInfo),
                {
                    method: 'post',
                    parameters: {
                        "ids[]": context._getPackagesIds()
                    },
                    onSuccess: function (transport) {
                        var response = transport.responseText.evalJSON();

                        if (!response.data) {
                            $(context._contentAreaId).update('');
                            if (response.statusMessages) {
                                $A(response.statusMessages).each(function (message) {
                                    context._addStatusMessage(message.status, message.content);
                                });
                            }
                            return;
                        }

                        if (!response.data.length) {
                            $(context._contentAreaId).update('');
                            context._addStatusMessage('info', context.lmsg('selectedPackagesUpToDate'));
                            return;
                        }

                        $(context._contentAreaId).update(
                            '<p>' + context.lmsg('popupUpdatePackagesListTitle') + '</p>' +
                            '<ul class="list-unordered">' + context._packages.map(context._getPackageHtml.bind(context)).join('') + '</ul>'
                        );

                        var packagesIds = context._getPackagesIds();
                        var dependencies = response.data.filter(function (pkg) {
                            return packagesIds.indexOf(pkg.name) === -1;
                        });

                        if (dependencies.length) {
                            $(context._contentAreaId).insert(
                                '<p><a href="#" class="toggler" onclick="$(this).up(\'.content-area\').select(\'ul.js-dependencies\').first().toggle()">' +
                                context.lmsg('popupUpdateDependencies', {count: dependencies.length}) +
                                '</a></p>' +
                                '<ul class="list-unordered js-dependencies" style="display:none;">' +
                                dependencies.map(context._getPackageHtml.bind(context)).join('') +
                                '</ul>'
                            );
                        }

                        var lockedPackages = response.data.filter(function (pkg) {
                            return pkg.locked;
                        });
                        if (lockedPackages.length) {
                            $(context._contentAreaId).insert(
                                '<hr>' +
                                '<div class="b-indent">' +
                                '<span class="b-indent-icon"><i class="icon-warning"></i></span>' +
                                '<p>' + context.lmsg('popupUpdateLockedPackagesListTitle') + '</p>' +
                                '<ul class="list-unordered">' +
                                lockedPackages.map(context._getPackageHtml.bind(context)).join('') +
                                '</ul>' +
                                '</div>' +
                                '<div class="form-row">' +
                                '<div class="single-row">' +
                                '<div class="indent-box">' +
                                '<input id="fid-unlock-packages" type="checkbox" class="checkbox" >' +
                                '<div class="indent-box-content">' +
                                '<label for="fid-unlock-packages">' + context.lmsg('unlockPackagesForUpdateOnly') + '</label>' +
                                '</div>' +
                                '</div>' +
                                '</div>' +
                                '</div>'
                            );
                            $('fid-unlock-packages').observe('click', function (event) {
                                context._updateButton(context._buttonOk, {disabled: !event.element().checked});
                            }.bind(context));
                        } else {
                            context._updateButton(context._buttonOk, {disabled: false});
                        }
                    }
                }
            );
        },

        _onOkClick: function (event) {
            var updateUrl = this._urls.updatePackages;
            var progressBar = Jsw.getComponent('asyncProgressBarWrapper');
            var itemId = progressBar.fly(event.target.cumulativeOffset(),
                this.lmsg('taskUpdatingPackages', {
                    count: this._packages.length
                }),
                function () {
                    new Ajax.Request(Jsw.prepareUrl(updateUrl), {
                        method: 'post',
                        parameters: {
                            "ids[]": this._getPackagesIds()
                        },
                        onSuccess: function () {
                            progressBar.removePreparingItem(itemId);
                            progressBar.update();
                        }
                    });
                }.bind(this)
            );
            this.remove();
            this.hide();
        }
    });
});
